2023-08-31 Version: 1.4.1
- Generated python2 2021-05-21 for ComputeNestSupplier.

2023-08-31 Version: 1.4.0
- Generated python2 2021-05-21 for ComputeNestSupplier.

2023-08-18 Version: 1.3.0
- Generated python2 2021-05-21 for ComputeNestSupplier.

2023-08-12 Version: 1.2.0
- Generated python2 2021-05-21 for ComputeNestSupplier.

2023-05-23 Version: 1.1.5
- Add UpdateService GetService DeleteService.

2023-05-16 Version: 1.1.4
- Add UpdateService GetService DeleteService.

2023-05-16 Version: 1.1.3
- Add response Permission.

2023-02-06 Version: 1.1.2
- Public ListServiceUsages  OpenApi.

2021-08-31 Version: 1.1.1
- Support ComputeNest Operation.

2021-08-31 Version: 1.1.0
- Support ComputeNest Operation.

2021-08-25 Version: 1.0.0
- The first version of ComputeNestSupplier SDK.

